<?php

namespace App\Http\Controllers;

use App\Models\Category;
use Illuminate\Http\Request;

class CategoryController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $categories = Category::latest()->get();
        return view('admin.allCategory', compact('categories'));
    }

    public function addCategory()
    {
        return view('admin.addCategory');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function storeCategory(Request $request)
    {
        $request->validate([
            'category_name' => 'required|unique:categories',
            'category_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'order' => 'required',
            'description' => 'required',
        ]);

        $image = $request->file('category_image');
        $img_name = hexdec(uniqid()) . '.' . $image->getClientOriginalName();
        $request->category_image->move(public_path('categories'), $img_name);
        $img_url = 'categories/' . $img_name;

        Category::insert([
            'category_name' => $request->category_name,
            'slug' => strtolower(str_replace('', '-', $request->category_name)),
            'category_image' => $img_url,
            'order' => $request->order,
            'description' => $request->description,
        ]);
        return redirect()->route('allcategory')->with('message', '成功添加分類');

    }

    /**
     * Show the form for editing the specified resource.
     */
    public function editCategory($id)
    {
        $category_info = Category::findOrFail($id);

        return view('admin.editCategory', compact('category_info'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function updateCategory(Request $request)
    {
        $category_id = $request->category_id;

        $request->validate([
            'category_name' => 'required|unique:categories',
            'category_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'order' => 'required',
            'description' => 'required',
        ]);

        $image = $request->file('category_image');
        $img_name = hexdec(uniqid()) . '.' . $image->getClientOriginalName();
        $request->category_image->move(public_path('categories'), $img_name);
        $img_url = 'categories/' . $img_name;

        Category::findOrFail($category_id)->update([
            'category_name' => $request->category_name,
            'slug' => strtolower(str_replace('', '-', $request->category_name)),
            'category_image' => $img_url,
            'order' => $request->order,
            'description' => $request->description,
        ]);
        return redirect()->route('allcategory')->with('message', '成功更改分類');
    }

    public function deleteCategory($id)
    {
        Category::findOrFail($id)->delete();
        return redirect()->route('allcategory')->with('message', '成功刪除分類');
    }

}
