<?php

namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\Category_lvl2;
use Illuminate\Http\Request;

class Category_lvl2Controller extends Controller
{
    public function index()
    {
        $lvl2categories = Category_lvl2::latest()->get();
        return view('admin.allCategory_lvl2', compact('lvl2categories'));
    }

    public function addCategorylvl2()
    {
        $categories = Category::latest()->get();
        return view('admin.addCategory_lvl2', compact('categories'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function storeCategorylvl2(Request $request)
    {
        $request->validate([
            'lvl2_category_name' => 'required|unique:category_lvl2s',
            'category_id' => 'required',
            'lvl2_category_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'order' => 'required',
            'description' => 'required',
        ]);

        $category_id = $request->category_id;
        $category_name = Category::where('id', $category_id)->value('category_name');

        $image = $request->file('lvl2_category_image');
        $img_name = hexdec(uniqid()) . '.' . $image->getClientOriginalName();
        $request->lvl2_category_image->move(public_path('categories'), $img_name);
        $img_url = 'categories/' . $img_name;

        Category_lvl2::insert([
            'lvl2_category_name' => $request->lvl2_category_name,
            'slug' => strtolower(str_replace('', '-', $request->lvl2_category_name)),
            'lvl2_category_image' => $img_url,
            'order' => $request->order,
            'description' => $request->description,
            'category_id' => $category_id,
            'category_name' => $category_name,
        ]);

        Category::where('id', $category_id)->increment('lvl2_category_count', 1);

        return redirect()->route('allcategorylvl2')->with('message', '成功添加分類');
    }

    public function editCategorylvl2($id)
    {
        $category_lvl2_info = Category_lvl2::findOrFail($id);

        return view('admin.editCategory_lvl2', compact('category_lvl2_info'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function updateCategorylvl2(Request $request)
    {
        $category_lvl2_id = $request->category_lvl2_id;

        $request->validate([
            'lvl2_category_name' => 'required|unique:category_lvl2s',
            'lvl2_category_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'order' => 'required',
            'description' => 'required',
        ]);

        $image = $request->file('lvl2_category_image');
        $img_name = hexdec(uniqid()) . '.' . $image->getClientOriginalName();
        $request->lvl2_category_image->move(public_path('categories'), $img_name);
        $img_url = 'categories/' . $img_name;

        Category_lvl2::findOrFail($category_lvl2_id)->update([
            'lvl2_category_name' => $request->lvl2_category_name,
            'slug' => strtolower(str_replace('', '-', $request->lvl2_category_name)),
            'lvl2_category_image' => $img_url,
            'order' => $request->order,
            'description' => $request->description,
        ]);
        return redirect()->route('allcategorylvl2')->with('message', '成功更新分類');
    }

    public function deleteCategorylvl2($id)
    {
        $category_id = Category_lvl2::where('id', $id)->value('category_id');
        Category_lvl2::findOrFail($id)->delete();

        Category::where('id', $category_id)->decrement('lvl2_category_count', 1);

        return redirect()->route('allcategorylvl2')->with('message', '成功刪除分類');
    }

}
