<?php

namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\Category_lvl2;
use App\Models\Category_lvl3;
use Illuminate\Http\Request;

class Category_lvl3Controller extends Controller
{
    public function index()
    {
        $lvl3categories = Category_lvl3::latest()->get();

        return view('admin.allCategory_lvl3', compact('lvl3categories'));
    }

    public function addCategorylvl3()
    {
        $categories = Category::latest()->get();
        $lvl2categories = Category_lvl2::latest()->get();
        return view('admin.addCategory_lvl3', compact('categories', 'lvl2categories'));
    }

    public function storeCategorylvl3(Request $request)
    {
        $request->validate([
            'lvl3_category_name' => 'required|unique:category_lvl3s',
            'category_id' => 'required',
            'lvl2_category_id' => 'required',
            'lvl3_category_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'order' => 'required',
            'description' => 'required',
        ]);

        $category_id = $request->category_id;
        $category_name = Category::where('id', $category_id)->value('category_name');

        $lvl2_category_id = $request->lvl2_category_id;
        $lvl2_category_name = Category_lvl2::where('id', $lvl2_category_id)->value('lvl2_category_name');

        $image = $request->file('lvl3_category_image');
        $img_name = hexdec(uniqid()) . '.' . $image->getClientOriginalName();
        $request->lvl3_category_image->move(public_path('categories'), $img_name);
        $img_url = 'categories/' . $img_name;

        Category_lvl3::insert([
            'lvl3_category_name' => $request->lvl3_category_name,
            'slug' => strtolower(str_replace('', '-', $request->lvl3_category_name)),
            'lvl3_category_image' => $img_url,
            'order' => $request->order,
            'description' => $request->description,
            'category_id' => $category_id,
            'category_name' => $category_name,
            'lvl2_category_id' => $lvl2_category_id,
            'lvl2_category_name' => $lvl2_category_name,
        ]);

        Category::where('id', $category_id)->increment('lvl3_category_count', 1);
        Category_lvl2::where('id', $lvl2_category_id)->increment('lvl3_category_count', 1);

        return redirect()->route('allcategorylvl3')->with('message', '成功添加分類');
    }

    public function editCategorylvl3($id)
    {
        $category_lvl3_info = Category_lvl3::findOrFail($id);

        return view('admin.editCategory_lvl3', compact('category_lvl3_info'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function updateCategorylvl3(Request $request)
    {
        $category_lvl3_id = $request->category_lvl3_id;

        $request->validate([
            'lvl3_category_name' => 'required|unique:category_lvl3s',
            'lvl3_category_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'order' => 'required',
            'description' => 'required',
        ]);

        $image = $request->file('lvl3_category_image');
        $img_name = hexdec(uniqid()) . '.' . $image->getClientOriginalName();
        $request->lvl3_category_image->move(public_path('categories'), $img_name);
        $img_url = 'categories/' . $img_name;

        Category_lvl3::findOrFail($category_lvl3_id)->update([
            'lvl3_category_name' => $request->lvl3_category_name,
            'slug' => strtolower(str_replace('', '-', $request->lvl3_category_name)),
            'lvl3_category_image' => $img_url,
            'order' => $request->order,
            'description' => $request->description,
        ]);
        return redirect()->route('allcategorylvl3')->with('message', '成功更新分類');
    }

    public function deleteCategorylvl3($id)
    {
        $category_id = Category_lvl3::where('id', $id)->value('category_id');
        Category_lvl3::findOrFail($id)->delete();

        Category::where('id', $category_id)->decrement('lvl3_category_count', 1);
        Category_lvl2::where('id', $category_id)->decrement('lvl3_category_count', 1);

        return redirect()->route('allcategorylvl3')->with('message', '成功刪除分類');
    }
}
