<?php

namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\Category_lvl2;
use App\Models\Category_lvl3;
use App\Models\Category_lvl4;
use Illuminate\Http\Request;

class Category_lvl4Controller extends Controller
{
    public function index()
    {
        $lvl4categories = Category_lvl4::latest()->get();

        return view('admin.allCategory_lvl4', compact('lvl4categories'));
    }

    public function addCategorylvl4()
    {
        $categories = Category::latest()->get();
        $lvl2categories = Category_lvl2::latest()->get();
        $lvl3categories = Category_lvl3::latest()->get();
        return view('admin.addCategory_lvl4', compact('categories', 'lvl2categories', 'lvl3categories'));
    }

    public function storeCategorylvl4(Request $request)
    {
        $request->validate([
            'lvl4_category_name' => 'required|unique:category_lvl4s',
            'category_id' => 'required',
            'lvl2_category_id' => 'required',
            'lvl3_category_id' => 'required',
            'lvl4_category_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'order' => 'required',
            'description' => 'required',
        ]);

        $category_id = $request->category_id;
        $category_name = Category::where('id', $category_id)->value('category_name');

        $lvl2_category_id = $request->lvl2_category_id;
        $lvl2_category_name = Category_lvl2::where('id', $lvl2_category_id)->value('lvl2_category_name');

        $lvl3_category_id = $request->lvl3_category_id;
        $lvl3_category_name = Category_lvl3::where('id', $lvl3_category_id)->value('lvl3_category_name');

        $image = $request->file('lvl4_category_image');
        $img_name = hexdec(uniqid()) . '.' . $image->getClientOriginalName();
        $request->lvl4_category_image->move(public_path('categories'), $img_name);
        $img_url = 'categories/' . $img_name;

        Category_lvl4::insert([
            'lvl4_category_name' => $request->lvl4_category_name,
            'slug' => strtolower(str_replace('', '-', $request->lvl4_category_name)),
            'lvl4_category_image' => $img_url,
            'order' => $request->order,
            'description' => $request->description,
            'category_id' => $category_id,
            'category_name' => $category_name,
            'lvl2_category_id' => $lvl2_category_id,
            'lvl2_category_name' => $lvl2_category_name,
            'lvl3_category_id' => $lvl3_category_id,
            'lvl3_category_name' => $lvl3_category_name,
        ]);

        Category::where('id', $category_id)->increment('lvl4_category_count', 1);
        Category_lvl2::where('id', $lvl2_category_id)->increment('lvl4_category_count', 1);
        Category_lvl3::where('id', $lvl3_category_id)->increment('lvl4_category_count', 1);

        return redirect()->route('allcategorylvl4')->with('message', '成功添加分類');
    }

    public function editCategorylvl4($id)
    {
        $category_lvl4_info = Category_lvl4::findOrFail($id);

        return view('admin.editCategory_lvl4', compact('category_lvl4_info'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function updateCategorylvl4(Request $request)
    {
        $category_lvl4_id = $request->category_lvl4_id;

        $request->validate([
            'lvl4_category_name' => 'required|unique:category_lvl4s',
            'lvl4_category_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'order' => 'required',
            'description' => 'required',
        ]);

        $image = $request->file('lvl4_category_image');
        $img_name = hexdec(uniqid()) . '.' . $image->getClientOriginalName();
        $request->lvl4_category_image->move(public_path('categories'), $img_name);
        $img_url = 'categories/' . $img_name;

        Category_lvl4::findOrFail($category_lvl4_id)->update([
            'lvl4_category_name' => $request->lvl4_category_name,
            'slug' => strtolower(str_replace('', '-', $request->lvl4_category_name)),
            'lvl4_category_image' => $img_url,
            'order' => $request->order,
            'description' => $request->description,
        ]);
        return redirect()->route('allcategorylvl4')->with('message', '成功更新分類');

    }

    public function deleteCategorylvl4($id)
    {
        $category_id = Category_lvl4::where('id', $id)->value('category_id');
        Category_lvl4::findOrFail($id)->delete();

        Category::where('id', $category_id)->decrement('lvl4_category_count', 1);
        Category_lvl2::where('id', $category_id)->decrement('lvl4_category_count', 1);
        Category_lvl3::where('id', $category_id)->decrement('lvl4_category_count', 1);

    }
}
