<?php

namespace App\Http\Controllers;

use App\Models\Brand;
use App\Models\Category;
use App\Models\Category_lvl2;
use App\Models\Category_lvl3;
use App\Models\Category_lvl4;
use App\Models\Color;
use App\Models\Origin;
use App\Models\Product;
use App\Models\Unit;
use Illuminate\Http\Request;

class ProductController extends Controller
{
    public function index()
    {
        $products = Product::latest()->get();
        return view('admin.allProduct', compact('products'));
    }

    public function addProduct()
    {
        $categories = Category::latest()->get();
        $lvl2categories = Category_lvl2::latest()->get();
        $lvl3categories = Category_lvl3::latest()->get();
        $lvl4categories = Category_lvl4::latest()->get();
        $brands = Brand::latest()->get();
        $colors = Color::latest()->get();
        $origins = Origin::latest()->get();
        $units = Unit::latest()->get();

        return view('admin.addProduct', compact(
            'categories',
            'lvl2categories',
            'lvl3categories',
            'lvl4categories',
            'brands',
            'colors',
            'origins',
            'units',
        ));
    }

    public function storeProduct(Request $request)
    {
        $request->validate([
            'product_name' => 'required|unique:products',
            'price' => 'required',
            'modal' => 'required',
            'size' => 'required',
            'product_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'category_id' => 'required',
            'lvl2_category_id' => 'required',
            'lvl3_category_id' => 'required',
            'lvl4_category_id' => 'required',
            'brand_id' => 'required',
            'color_id' => 'required',
            'origin_id' => 'required',
            'unit_id' => 'required',
            'description' => 'required',
        ]);

        $image = $request->file('product_image');
        $img_name = hexdec(uniqid()) . '.' . $image->getClientOriginalName();
        $request->product_image->move(public_path('products'), $img_name);
        $img_url = 'products/' . $img_name;

        $category_id = $request->category_id;
        $lvl2_category_id = $request->lvl2_category_id;
        $lvl3_category_id = $request->lvl3_category_id;
        $lvl4_category_id = $request->lvl4_category_id;
        $brand_id = $request->brand_id;
        $color_id = $request->color_id;
        $origin_id = $request->origin_id;
        $unit_id = $request->unit_id;

        $category_name = Category::where('id', $category_id)->value('category_name');
        $lvl2_category_name = Category_lvl2::where('id', $lvl2_category_id)->value('lvl2_category_name');
        $lvl3_category_name = Category_lvl3::where('id', $lvl3_category_id)->value('lvl3_category_name');
        $lvl4_category_name = Category_lvl4::where('id', $lvl4_category_id)->value('lvl4_category_name');
        $brand_name = Brand::where('id', $brand_id)->value('brand_name');
        $color_name = Color::where('id', $color_id)->value('color_name');
        $origin_name = Origin::where('id', $origin_id)->value('origin_name');
        $unit_name = Unit::where('id', $unit_id)->value('unit_name');

        Product::insert([
            'product_name' => $request->product_name,
            'slug' => strtolower(str_replace('', '-', $request->product_name)),
            'price' => $request->price,
            'modal' => $request->modal,
            'size' => $request->size,
            'product_image' => $img_url,
            'category_id' => $category_id,
            'category_name' => $category_name,
            'lvl2_category_id' => $lvl2_category_id,
            'lvl2_category_name' => $lvl2_category_name,
            'lvl3_category_id' => $lvl3_category_id,
            'lvl3_category_name' => $lvl3_category_name,
            'lvl4_category_id' => $lvl4_category_id,
            'lvl4_category_name' => $lvl4_category_name,
            'brand_id' => $brand_id,
            'brand_name' => $brand_name,
            'color_id' => $color_id,
            'color_name' => $color_name,
            'origin_id' => $origin_id,
            'origin_name' => $origin_name,
            'unit_id' => $unit_id,
            'unit_name' => $unit_name,
            'description' => $request->description,
        ]);

        Category::where('id', $category_id)->increment('product_count', 1);
        Category_lvl2::where('id', $lvl2_category_id)->increment('product_count', 1);
        Category_lvl3::where('id', $lvl3_category_id)->increment('product_count', 1);
        Category_lvl4::where('id', $lvl4_category_id)->increment('product_count', 1);

        return redirect()->route('allproduct')->with('message', '成功添加商品');

    }

    /**
     * Show the form for editing the specified resource.
     */
    public function editProduct($id)
    {
        $product_info = Product::findOrFail($id);

        return view('admin.editProduct', compact('product_info'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function updateProduct(Request $request)
    {
        $product_id = $request->product_id;

        $request->validate([
            'product_name' => 'required|unique:products',
            'price' => 'required',
            'product_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'description' => 'required',
        ]);

        $image = $request->file('product_image');
        $img_name = hexdec(uniqid()) . '.' . $image->getClientOriginalName();
        $request->product_image->move(public_path('products'), $img_name);
        $img_url = 'products/' . $img_name;

        Product::findOrFail($product_id)->update([
            'product_name' => $request->product_name,
            'slug' => strtolower(str_replace('', '-', $request->product_name)),
            'price' => $request->price,
            'product_image' => $img_url,
            'description' => $request->description,
        ]);

        return redirect()->route('allproduct')->with('message', '成功更新商品');
    }

    public function deleteProduct($id)
    {
        $category_id = Product::where('id', $id)->value('category_id');
        $category_lvl2_id = Product::where('id', $id)->value('lvl2_category_id');

        Category::where('id', $category_id)->decrement('product_count', 1);
        Category_lvl2::where('id', $category_lvl2_id)->decrement('product_count', 1);
        Product::findOrFail($id)->delete();

        return redirect()->route('allproduct')->with('message', '成功刪除商品');

    }

}
